# Fedora/remirepo spec file for php-doctrine-annotations2
#
# Copyright (c) 2013-2023 Remi Collet, Shawn Iwinski
#
# License: MIT
# http://opensource.org/licenses/MIT
#
# Please preserve changelog entries
#

# Build using "--without tests" to disable tests
%bcond_without tests

%global github_owner     doctrine
%global github_name      annotations
%global github_version   2.0.1
%global github_commit    e157ef3f3124bbf6fe7ce0ffd109e8a8ef284e7f
%global major            2

%global composer_vendor  doctrine
%global composer_project annotations

# "php": "^7.2 || ^8.0"
%global php_min_ver      7.2
# "doctrine/cache": "^2.0"
# ignore min version for now
%global cache_min_ver    1.11
%global cache_max_ver    3
# "doctrine/lexer": "^2 || ^3"
%global lexer_min_ver    2
%global lexer_max_ver    4
# "psr/cache": "^1 || ^2 || ^3"
%global psr_cache_min_ver 1
# only v1 is available for now
%global psr_cache_max_ver 2
# "symfony/cache": "^5.4 || ^6.0"
# ignore min version for now
%global symfony_min_ver 4.4
%global symfony_max_ver 7


%{!?phpdir:  %global phpdir  %{_datadir}/php}

Name:          php-%{composer_vendor}-%{composer_project}%{major}
Version:       %{github_version}
Release:       1%{?github_release}%{?dist}
Summary:       PHP docblock annotations parser library

License:       MIT
URL:           https://github.com/%{github_owner}/%{github_name}

# GitHub export does not include tests.
# Run php-doctrine-annotations-get-source.sh to create full source.
Source0:       %{name}-%{version}-%{github_commit}.tar.gz
Source1:       %{name}-get-source.sh

BuildArch:     noarch
# Tests
%if %{with tests}
## composer.json
BuildRequires: php(language) >= %{php_min_ver}
# remirepo:1
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
BuildRequires:(php-composer(doctrine/cache) >= %{cache_min_ver} with php-composer(doctrine/cache) < %{cache_max_ver})
BuildRequires:(php-composer(doctrine/lexer) >= %{lexer_min_ver} with php-composer(doctrine/lexer) < %{lexer_max_ver})
BuildRequires:(php-composer(psr/cache) >= %{psr_cache_min_ver} with php-composer(psr/cache) < %{psr_cache_max_ver})
BuildRequires:(php-composer(symfony/cache) >= %{symfony_min_ver} with php-composer(symfony/cache) < %{symfony_max_ver})
# remirepo:8
%else
BuildRequires: php-doctrine-cache <  %{cache_max_ver}
BuildRequires: php-doctrine-cache >= %{cache_min_ver}
BuildRequires: php-doctrine-lexer2 <  %{lexer_max_ver}
BuildRequires: php-doctrine-lexer2 >= %{lexer_min_ver}
BuildRequires: php-psr-cache >= %{psr_cache_min_ver}
BuildRequires: php-symfony4-cache >= %{symfony_min_ver}
%endif
# "phpunit/phpunit": "^7.5 || ^8.5 || ^9.5"
%global phpunit %{_bindir}/phpunit9
BuildRequires: phpunit9 >= 9.5

## phpcompatinfo (computed from version 1.10.0)
BuildRequires: php-ctype
BuildRequires: php-date
BuildRequires: php-json
BuildRequires: php-mbstring
BuildRequires: php-pcre
BuildRequires: php-reflection
BuildRequires: php-spl
BuildRequires: php-tokenizer
%endif
# Autoloader
BuildRequires: php-fedora-autoloader-devel

# composer.json
Requires:      php(language) >= %{php_min_ver}
Requires:      php-tokenizer
# remirepo:1
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
Requires:     (php-composer(doctrine/lexer) >= %{lexer_min_ver} with php-composer(doctrine/lexer) < %{lexer_max_ver})
Requires:     (php-composer(psr/cache) >= %{psr_cache_min_ver} with php-composer(psr/cache) < %{psr_cache_max_ver})
# remirepo:6
%else
Requires:      php-doctrine-lexer2 <  %{lexer_max_ver}
Requires:      php-doctrine-lexer2 >= %{lexer_min_ver}
Requires:      php-psr-cache <  %{psr_cache_max_ver}
Requires:      php-psr-cache >= %{psr_cache_min_ver}
%endif
# phpcompatinfo (computed from version 1.10.0)
Requires:      php-ctype
Requires:      php-date
Requires:      php-json
Requires:      php-pcre
Requires:      php-reflection
Requires:      php-spl
# Autoloader
Requires:      php-composer(fedora/autoloader)

# Composer
Provides:      php-composer(%{composer_vendor}/%{composer_project}) = %{version}

# Extracted from Doctrine Common as of version 2.4
Conflicts:     php-pear(pear.doctrine-project.org/DoctrineCommon) < 2.4

%description
%{summary} (extracted from Doctrine Common).

Autoloader: %{phpdir}/Doctrine/Common/Annotations%{major}/autoload.php


%prep
%setup -qn %{github_name}-%{github_commit}


%build
: Generate a simple autoloader
%{_bindir}/phpab \
    --output lib/Doctrine/Common/Annotations/autoload.php \
    --template fedora \
    lib/Doctrine/Common/Annotations

cat <<'AUTOLOAD' | tee -a lib/Doctrine/Common/Annotations/autoload.php

\Fedora\Autoloader\Dependencies::required([
    [
        '%{phpdir}/Doctrine/Common/Lexer3/autoload.php',
        '%{phpdir}/Doctrine/Common/Lexer2/autoload.php',
    ],
    '%{phpdir}/Psr/Cache/autoload.php',
]);
AUTOLOAD


%install
mkdir -p %{buildroot}%{phpdir}/Doctrine/Common
cp -rp lib/Doctrine/Common/Annotations %{buildroot}%{phpdir}/Doctrine/Common/Annotations%{major}


%check
%if %{with tests}
: Create tests bootstrap
mkdir vendor
cat <<'BOOTSTRAP' | tee vendor/autoload.php
<?php
require_once '%{buildroot}%{phpdir}/Doctrine/Common/Annotations%{major}/autoload.php';
\Fedora\Autoloader\Dependencies::required([
    [
        '%{phpdir}/Doctrine/Common/Cache2/autoload.php',
        '%{phpdir}/Doctrine/Common/Cache/autoload.php',
    ], [
        '%{phpdir}/Symfony6/Component/Cache/autoload.php',
        '%{phpdir}/Symfony5/Component/Cache/autoload.php',
        '%{phpdir}/Symfony4/Component/Cache/autoload.php',
    ],
    dirname( __DIR__) . '/tests/Doctrine/Tests/TestInit.php',
    dirname( __DIR__) . '/tests/Doctrine/Tests/Common/Annotations/Fixtures/functions.php',
    dirname( __DIR__) . '/tests/Doctrine/Tests/Common/Annotations/Fixtures/SingleClassLOC1000.php',
]);
BOOTSTRAP

: Upstream tests
RETURN_CODE=0
for CMD in "php %{phpunit}" php80 php81 php82; do
    if which $CMD; then
        set $CMD
        $1 ${2:-%{_bindir}/phpunit9} --verbose \
            -d pcre.recursion_limit=10000 \
            --filter '^((?!(testAvoidCallingFilemtimeTooMuch)).)*$' \
            || RETURN_CODE=1
    fi
done
exit $RETURN_CODE
%else
: Tests skipped
%endif


%files
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc *.md
%doc composer.json
%{phpdir}/Doctrine/Common/Annotations%{major}


%changelog
* Fri Feb  3 2023 Remi Collet <remi@remirepo.net> - 2.0.1-1
- update to 2.0.1

* Tue Dec 20 2022 Remi Collet <remi@remirepo.net> - 2.0.0-1
- update to 2.0.0
- rename to php-doctrine-annotations2
- install in /usr/share/php/Doctrine/Common/Annotations2
- switch to classmap autoloader
- raise dependency on PHP 7.2
- raise dependency on doctrine/lexer 2 or 3

* Tue Dec 20 2022 Remi Collet <remi@remirepo.net> - 1.14.2-1
- update to 1.14.2

* Tue Dec 13 2022 Remi Collet <remi@remirepo.net> - 1.14.1-1
- update to 1.14.1
- allow doctrine/lexer v2

* Mon Jul  4 2022 Remi Collet <remi@remirepo.net> - 1.13.3-1
- update to 1.13.3

* Fri Aug  6 2021 Remi Collet <remi@remirepo.net> - 1.13.2-1
- update to 1.13.2

* Mon May 17 2021 Remi Collet <remi@remirepo.net> - 1.13.1-2
- allow doctrine/cache v2

* Mon May 17 2021 Remi Collet <remi@remirepo.net> - 1.13.1-1
- update to 1.13.1
- add runtime dependency on psr/cache
- add build dependency on symfony/cache

* Wed Feb 24 2021 Remi Collet <remi@remirepo.net> - 1.12.1-1
- update to 1.12.1

* Tue Oct 27 2020 Remi Collet <remi@remirepo.net> - 1.11.1-1
- update to 1.11.1

* Mon Oct 26 2020 Remi Collet <remi@remirepo.net> - 1.11.0-1
- update to 1.11.0

* Wed Aug 12 2020 Remi Collet <remi@remirepo.net> - 1.10.4-1
- update to 1.10.4
- switch to phpunit9

* Tue May 26 2020 Remi Collet <remi@remirepo.net> - 1.10.3-1
- update to 1.10.3 (no change)

* Mon Apr 20 2020 Remi Collet <remi@remirepo.net> - 1.10.2-1
- update to 1.10.2

* Thu Apr  2 2020 Remi Collet <remi@remirepo.net> - 1.10.1-1
- update to 1.10.1

* Thu Apr  2 2020 Remi Collet <remi@remirepo.net> - 1.10.0-1
- update to 1.10.0

* Wed Oct  2 2019 Remi Collet <remi@remirepo.net> - 1.8.0-1
- update to 1.8.0

* Mon Aug 19 2019 Remi Collet <remi@remirepo.net> - 1.7.0-1
- update to 1.7.0
- switch to phpunit7

* Tue Mar 26 2019 Remi Collet <remi@remirepo.net> - 1.6.1-1
- update to 1.6.1

* Wed Oct 17 2018 Remi Collet <remi@remirepo.net> - 1.6.0-1
- update to 1.6.0
- raise dependency on PHP 7.1
- use phpunit6
- use range dependencies

* Fri May 12 2017 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.2.7-4
- Switch autoloader to php-composer(fedora/autoloader)
- Add max versions to build dependencies
- Test with SCLs if available

* Sat Sep 05 2015 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.2.7-1
- Updated to 1.2.7 (RHBZ #1258669 / CVE-2015-5723)
- Updated autoloader to load dependencies after self registration

* Sat Jun 27 2015 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.2.6-2
- Updated autoloader with trailing separator

* Wed Jun 24 2015 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.2.6-1
- Updated to 1.2.6 (RHBZ #1211816)
- Added autoloader

* Sun Dec 28 2014 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.2.3-1
- Updated to 1.2.3 (BZ #1176942)

* Sun Oct 19 2014 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.2.1-1
- Updated to 1.2.1 (BZ #1146910)
- %%license usage

* Mon Sep 29 2014 Remi Collet <remi@fedoraproject.org> - 1.2.1-1
- update to 1.2.1

* Thu Jul 17 2014 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.2.0-2
- Removed skipping of test (php-phpunit-PHPUnit-MockObject patched to fix issue)

* Tue Jul 15 2014 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.2.0-1
- Updated to 1.2.0 (BZ #1116887)

* Fri Jun 20 2014 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.1.2-5.20131220gita11349d
- Added php-composer(%%{composer_vendor}/%%{composer_project}) virtual provide
- Added option to build without tests ("--without tests")
- Updated dependencies to use php-composer virtual provides

* Sat Jan 11 2014 Remi Collet <rpms@famillecollet.com> 1.1.2-3.20131220gita11349d
- backport for remi repo

* Mon Jan 06 2014 Shawn Iwinski <shawn.iwinski@gmail.com> 1.1.2-3.20131220gita11349d
- Minor syntax changes

* Fri Jan 03 2014 Shawn Iwinski <shawn.iwinski@gmail.com> 1.1.2-2.20131220gita11349d
- Conditional %%{?dist}
- Added conflict w/ PEAR-based DoctrineCommon pkg (version < 2.4)

* Mon Dec 23 2013 Shawn Iwinski <shawn.iwinski@gmail.com> 1.1.2-1.20131220gita11349d
- Initial package
